function PlotMonthlyLST(DataFolder,Name,location,X1, Y1, E1, Y2, E2, Y3, E3,Y4, E4, Y5, E5, Y6, E6,Y7, E7)
% SUBFUNCTION of ProcessedMonthlyMean; Plots monthly means of FitParameters.
% For more info on FitParameters see FitData. For more info on structure Data see readData   
%
%Name:  Data.Name
%X1:    1:12.
%Y1:    Data.Processed.Monthly.Mean.a0
%E1:    Data.Processed.Monthly.STD.a0
%Y2:    Data.Processed.Monthly.Mean.a1
%E2:    Data.Processed.Monthly.STD.a1
%Y3:    Data.Processed.Monthly.Mean.c1
%E3:    Data.Processed.Monthly.STD.c1
%Y4:    Data.Processed.Monthly.Mean.a2
%E4:    Data.Processed.Monthly.STD.a2
%Y5:    Data.Processed.Monthly.Mean.c2
%E5:    Data.Processed.Monthly.STD.c2
%Y6:    Data.Processed.Monthly.Mean.a3
%E6:    Data.Processed.Monthly.STD.a3
%Y7:    Data.Processed.Monthly.Mean.c3
%E7:    Data.Processed.Monthly.STD.c3


% Create figure
figure1 = figure('NumberTitle','off','Name',Name,'units','centimeters','Position',[0 0 21 25],...                    % setter str på figuren du vil se på skjermen. VIKIT Gat units kommer FØR Position
    'PaperUnits','centimeters','PaperPosition', [0 0 21 25],...% setter str på figuren du vil lagre (uavhengig av format) VIKITG at units kommer FØR Position
    'DefaultAxesFontSize',14,'DefaultAxesFontWeight','b');               %setter str på font i figure 


% Create axes
axes1 = axes('Parent',figure1,...
    'Position',[0.13 0.772379703440585 0.772413431269675 0.157741935483871]);
box(axes1,'on');
hold(axes1,'all');

% Create errorbar
errorbar(X1,Y1,E1,'LineWidth',2,'Parent',axes1,'Color',[0 0 0]);
 xlim(axes1,[0.5 12.5]);
 ylim(axes1,[-10 5])
% Create xlabel
xlabel({'month',''});

% Create ylabel
ylabel({'a_0 [m/s]',''});

% Create axes
axes2 = axes('Parent',figure1,...
    'Position',[0.13 0.552013272204093 0.334659090909091 0.157741935483871]);
% Uncomment the following line to preserve the X-limits of the axes
% xlim(axes2,[0.5 12.5]);
box(axes2,'on');
hold(axes2,'all');

% Create errorbar
errorbar(X1,Y2,E2,'LineWidth',2,'Parent',axes2,'Color',[0 0 0]);
 xlim(axes2,[0.5 12.5]);
 ylim(axes2,[0 20])
% Create xlabel
xlabel('month');

% Create ylabel
ylabel('a_1 [m/s]');

% Create axes
axes3 = axes('Parent',figure1,...
    'Position',[0.570340909090909 0.552013272204093 0.334659090909091 0.157741935483871]);
% Uncomment the following line to preserve the X-limits of the axes
xlim(axes3,[0.5 12.5]);
% Uncomment the following line to preserve the Y-limits of the axes
ylim(axes3,[0 25]);
box(axes3,'on');
hold(axes3,'all');
set(gca,'ytick',[0:3:36])
set(gca,'ytickLabel',[0:3:24])
% Create errorbar
errorbar(X1,Y3,E3,'LineWidth',2,'Parent',axes3,'Color',[0 0 0],'Marker','.','LineStyle','none');
errorbar(X1,Y3+24,E3,'LineWidth',2,'Parent',axes3,'Color',[0 0 0],'Marker','.','LineStyle','none');
errorbar(X1,Y3-24,E3,'LineWidth',2,'Parent',axes3,'Color',[0 0 0],'Marker','.','LineStyle','none');
% Create xlabel
xlabel('month');

% Create ylabel
ylabel('c_1 [LST]');

% Create axes
axes4 = axes('Parent',figure1,...
    'Position',[0.13 0.295795368496413 0.334659090909091 0.157741935483871]);
% Uncomment the following line to preserve the X-limits of the axes
xlim(axes4,[0.5 12.5]);
ylim(axes4,[0 20]);
box(axes4,'on');
hold(axes4,'all');

% Create errorbar
errorbar(X1,Y4,E4,'LineWidth',2,'Parent',axes4,'Color',[0 0 0]);

% Create xlabel
xlabel('month');

% Create ylabel
ylabel('a_2 [m/s]');

% Create axes
axes5 = axes('Parent',figure1,...
    'Position',[0.570340909090909 0.295795368496413 0.334659090909091 0.157741935483871]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim(axes5,[0.5 12.5]);
 ylim(axes5,[0 13]);

box(axes5,'on');
hold(axes5,'all');

% Create errorbar
errorbar(X1,Y5,E5,'LineWidth',2,'Parent',axes5,'Color',[0 0 0],'Marker','.','LineStyle','none');
errorbar(X1,Y5+12,E5,'LineWidth',2,'Parent',axes5,'Color',[0 0 0],'Marker','.','LineStyle','none');
errorbar(X1,Y5-12,E5,'LineWidth',2,'Parent',axes5,'Color',[0 0 0],'Marker','.','LineStyle','none');
set(gca,'ytick',[0:2:25])
set(gca,'ytickLabel',[0:2:12])
% Create xlabel
xlabel('month');

% Create ylabel
ylabel('c_2 [LST]');

% Create axes
axes6 = axes('Parent',figure1,...
    'Position',[0.13 0.04 0.334659090909091 0.157741935483871]);
% Uncomment the following line to preserve the X-limits of the axes
 xlim(axes6,[0.5 12.5]);
 ylim(axes6,[0 20]);
box(axes6,'on');
hold(axes6,'all');

% Create errorbar
errorbar(X1,Y6,E6,'LineWidth',2,'Parent',axes6,'Color',[0 0 0]);

% Create xlabel
xlabel('month');

% Create ylabel
ylabel('a_3 [m/s]');

% % Create axes
% axes7 = axes('Parent',figure1,...
%     'Position',[0.570340909090909 0.04 0.334659090909091 0.157741935483871]);
% % Uncomment the following line to preserve the X-limits of the axes
%  xlim(axes7,[0.5 12.5]);
% % Uncomment the following line to preserve the Y-limits of the axes
%  ylim(axes7,[0 48]);
% box(axes7,'on');
% hold(axes7,'all');
%  
%  set(gca,'ytick',[0:6:49])
% set(gca,'ytickLabel',[0:6:48])
% % Create errorbar
% errorbar(X1,Y7,E7,'LineWidth',2,'Parent',axes7,'Color',[0 0 0]);
% 
% % Create xlabel
% xlabel('month');
% 
% % Create ylabel
% ylabel('c_3 [LST]');

% Create textbox
annotation(figure1,'textbox',...
    [0.419677859391397 0.973111395646606 0.180532004197272 0.0166453265044809],...
    'Interpreter','none',...    
    'String',{Name},...
    'HorizontalAlignment','center',...
    'FontSize',14,...
    'FitBoxToText','off',...
    'LineStyle','none');


filename=[Name,'.fig'];
saveas(figure1,fullfile(DataFolder,location,filename))


end